@@ -121,6 +121,7 @@ _TESTED_OS_VERSIONS = [
     ("12", "4"),
     ("12", "5"),
     ("12", "6"),
+    ("13", "0"),
 ]
 
 # Photos 5 has persons who are empty string if unidentified face
@@ -171,64 +172,99 @@ _MAX_IPTC_KEYWORD_LEN = 64
 # If anyone has a keyword matching this, then too bad...
 _OSXPHOTOS_NONE_SENTINEL = "OSXPhotosXYZZY42_Sentinel$"
 
-# SearchInfo categories for Photos 5, corresponds to categories in database/search/psi.sqlite
-SEARCH_CATEGORY_LABEL = 2024
-SEARCH_CATEGORY_PLACE_NAME = 1
-SEARCH_CATEGORY_STREET = 2
-SEARCH_CATEGORY_NEIGHBORHOOD = 3
-SEARCH_CATEGORY_LOCALITY_4 = 4
-SEARCH_CATEGORY_SUB_LOCALITY_5 = 5
-SEARCH_CATEGORY_SUB_LOCALITY_6 = 6
-SEARCH_CATEGORY_CITY = 7
-SEARCH_CATEGORY_LOCALITY_8 = 8
-SEARCH_CATEGORY_NAMED_AREA = 9
-SEARCH_CATEGORY_ALL_LOCALITY = [
-    SEARCH_CATEGORY_LOCALITY_4,
-    SEARCH_CATEGORY_SUB_LOCALITY_5,
-    SEARCH_CATEGORY_SUB_LOCALITY_6,
-    SEARCH_CATEGORY_LOCALITY_8,
-    SEARCH_CATEGORY_NAMED_AREA,
-]
-SEARCH_CATEGORY_STATE = 10
-SEARCH_CATEGORY_STATE_ABBREVIATION = 11
-SEARCH_CATEGORY_COUNTRY = 12
-SEARCH_CATEGORY_BODY_OF_WATER = 14
-SEARCH_CATEGORY_MONTH = 1014
-SEARCH_CATEGORY_YEAR = 1015
-SEARCH_CATEGORY_KEYWORDS = 2016
-SEARCH_CATEGORY_TITLE = 2017
-SEARCH_CATEGORY_DESCRIPTION = 2018
-SEARCH_CATEGORY_HOME = 2020
-SEARCH_CATEGORY_PERSON = 2021
-SEARCH_CATEGORY_ACTIVITY = 2027
-SEARCH_CATEGORY_HOLIDAY = 2029
-SEARCH_CATEGORY_SEASON = 2030
-SEARCH_CATEGORY_WORK = 2036
-SEARCH_CATEGORY_VENUE = 2038
-SEARCH_CATEGORY_VENUE_TYPE = 2039
-SEARCH_CATEGORY_PHOTO_TYPE_VIDEO = 2044
-SEARCH_CATEGORY_PHOTO_TYPE_SLOMO = 2045
-SEARCH_CATEGORY_PHOTO_TYPE_LIVE = 2046
-SEARCH_CATEGORY_PHOTO_TYPE_SCREENSHOT = 2047
-SEARCH_CATEGORY_PHOTO_TYPE_PANORAMA = 2048
-SEARCH_CATEGORY_PHOTO_TYPE_TIMELAPSE = 2049
-SEARCH_CATEGORY_PHOTO_TYPE_BURSTS = 2052
-SEARCH_CATEGORY_PHOTO_TYPE_PORTRAIT = 2053
-SEARCH_CATEGORY_PHOTO_TYPE_SELFIES = 2054
-SEARCH_CATEGORY_PHOTO_TYPE_FAVORITES = 2055
-SEARCH_CATEGORY_MEDIA_TYPES = [
-    SEARCH_CATEGORY_PHOTO_TYPE_VIDEO,
-    SEARCH_CATEGORY_PHOTO_TYPE_SLOMO,
-    SEARCH_CATEGORY_PHOTO_TYPE_LIVE,
-    SEARCH_CATEGORY_PHOTO_TYPE_SCREENSHOT,
-    SEARCH_CATEGORY_PHOTO_TYPE_PANORAMA,
-    SEARCH_CATEGORY_PHOTO_TYPE_TIMELAPSE,
-    SEARCH_CATEGORY_PHOTO_TYPE_BURSTS,
-    SEARCH_CATEGORY_PHOTO_TYPE_PORTRAIT,
-    SEARCH_CATEGORY_PHOTO_TYPE_SELFIES,
-    SEARCH_CATEGORY_PHOTO_TYPE_FAVORITES,
-]
-SEARCH_CATEGORY_PHOTO_NAME = 2056
+
+class SearchCategory:
+    """SearchInfo categories for Photos 5+; corresponds to categories in database/search/psi.sqlite:groups.category
+
+    Note: This is a simple enum class; the values are not meant to be changed.
+    Would be great if Python enums actually let you access the value directly.
+    """
+
+    LABEL = 2024
+    PLACE_NAME = 1
+    STREET = 2
+    NEIGHBORHOOD = 3
+    LOCALITY_4 = 4
+    SUB_LOCALITY_5 = 5
+    SUB_LOCALITY_6 = 6
+    CITY = 7
+    LOCALITY_8 = 8
+    NAMED_AREA = 9
+    ALL_LOCALITY = [
+        LOCALITY_4,
+        SUB_LOCALITY_5,
+        SUB_LOCALITY_6,
+        LOCALITY_8,
+        NAMED_AREA,
+    ]
+    STATE = 10
+    STATE_ABBREVIATION = 11
+    COUNTRY = 12
+    BODY_OF_WATER = 14
+    MONTH = 1014
+    YEAR = 1015
+    KEYWORDS = 2016
+    TITLE = 2017
+    DESCRIPTION = 2018
+    HOME = 2020
+    PERSON = 2021
+    ACTIVITY = 2027
+    HOLIDAY = 2029
+    SEASON = 2030
+    WORK = 2036
+    VENUE = 2038
+    VENUE_TYPE = 2039
+    PHOTO_TYPE_VIDEO = 2044
+    PHOTO_TYPE_SLOMO = 2045
+    PHOTO_TYPE_LIVE = 2046
+    PHOTO_TYPE_SCREENSHOT = 2047
+    PHOTO_TYPE_PANORAMA = 2048
+    PHOTO_TYPE_TIMELAPSE = 2049
+    PHOTO_TYPE_BURSTS = 2052
+    PHOTO_TYPE_PORTRAIT = 2053
+    PHOTO_TYPE_SELFIES = 2054
+    PHOTO_TYPE_FAVORITES = 2055
+    MEDIA_TYPES = [
+        PHOTO_TYPE_VIDEO,
+        PHOTO_TYPE_SLOMO,
+        PHOTO_TYPE_LIVE,
+        PHOTO_TYPE_SCREENSHOT,
+        PHOTO_TYPE_PANORAMA,
+        PHOTO_TYPE_TIMELAPSE,
+        PHOTO_TYPE_BURSTS,
+        PHOTO_TYPE_PORTRAIT,
+        PHOTO_TYPE_SELFIES,
+        PHOTO_TYPE_FAVORITES,
+    ]
+    PHOTO_NAME = 2056
+    CAMERA = None  # Photos 8+ only
+    DETECTED_TEXT = None  # Photos 8+ only
+
+
+class SearchCategory_Photos8(SearchCategory):
+    """Search categories for Photos 8"""
+
+    # Many of the category values changed in Ventura / Photos 8
+    # and some new categories were added
+    LABEL = 1500
+    MONTH = 1100
+    YEAR = 1101
+    HOLIDAY = 1103
+    SEASON = 1104
+    KEYWORDS = 1200
+    TITLE = 1201
+    DESCRIPTION = 1202
+    DETECTED_TEXT = 1203  # new in Photos 8
+    PERSON = 1300
+    ACTIVITY = 1600
+    PHOTO_TYPE_FAVORITES = 2000
+    PHOTO_NAME = 2100
+    CAMERA = 2300  # new in Photos 8
+
+
+def search_category_factory(version: int) -> SearchCategory:
+    """Return SearchCategory class for Photos version"""
+    return SearchCategory_Photos8 if version >= 8 else SearchCategory
 
 
 # Max filename length on MacOS
