@@ -32,7 +32,7 @@ def detect_text(img_path: str, orientation: Optional[int] = None) -> List:
         orientation: optional EXIF orientation (if known, passing orientation may improve quality of results)
     """
     if not vision:
-        logging.warning(f"detect_text not implemented for this version of macOS")
+        logging.warning("detect_text not implemented for this version of macOS")
         return []
 
     with objc.autorelease_pool():
@@ -47,18 +47,18 @@ def detect_text(img_path: str, orientation: Optional[int] = None) -> List:
             input_image = Quartz.CIImage.imageWithContentsOfURL_(input_url)
 
         vision_options = NSDictionary.dictionaryWithDictionary_({})
-        if orientation is not None:
-            if not 1 <= orientation <= 8:
-                raise ValueError("orientation must be between 1 and 8")
-            vision_handler = Vision.VNImageRequestHandler.alloc().initWithCIImage_orientation_options_(
-                input_image, orientation, vision_options
-            )
-        else:
+        if orientation is None:
             vision_handler = (
                 Vision.VNImageRequestHandler.alloc().initWithCIImage_options_(
                     input_image, vision_options
                 )
             )
+        elif 1 <= orientation <= 8:
+            vision_handler = Vision.VNImageRequestHandler.alloc().initWithCIImage_orientation_options_(
+                input_image, orientation, vision_options
+            )
+        else:
+            raise ValueError("orientation must be between 1 and 8")
         results = []
         handler = make_request_handler(results)
         vision_request = (
